@@ -84,8 +84,8 @@ struct GsAppPrivate
 	GsAppRatingKind		 rating_kind;
 	guint64			 size;
 	GsAppKind		 kind;
-	GsAppIdKind		 id_kind;
-	GsAppState		 state;
+	AsIdKind		 id_kind;
+	AsAppState		 state;
 	GHashTable		*metadata;
 	GdkPixbuf		*pixbuf;
 	GdkPixbuf		*featured_pixbuf;
@@ -153,65 +153,18 @@ gs_app_kind_to_string (GsAppKind kind)
 	return NULL;
 }
 
-/**
- * gs_app_state_to_string:
- **/
-const gchar *
-gs_app_state_to_string (GsAppState state)
-{
-	if (state == GS_APP_STATE_UNKNOWN)
-		return "unknown";
-	if (state == GS_APP_STATE_INSTALLED)
-		return "installed";
-	if (state == GS_APP_STATE_AVAILABLE)
-		return "available";
-	if (state == GS_APP_STATE_LOCAL)
-		return "local";
-	if (state == GS_APP_STATE_QUEUED)
-		return "queued";
-	if (state == GS_APP_STATE_INSTALLING)
-		return "installing";
-	if (state == GS_APP_STATE_REMOVING)
-		return "removing";
-	if (state == GS_APP_STATE_UPDATABLE)
-		return "updatable";
-	if (state == GS_APP_STATE_UNAVAILABLE)
-		return "unavailable";
-	return NULL;
-}
-
-/**
- * gs_app_id_kind_to_string:
- **/
-const gchar *
-gs_app_id_kind_to_string (GsAppIdKind id_kind)
-{
-	if (id_kind == GS_APP_ID_KIND_UNKNOWN)
-		return "unknown";
-	if (id_kind == GS_APP_ID_KIND_DESKTOP)
-		return "desktop";
-	if (id_kind == GS_APP_ID_KIND_INPUT_METHOD)
-		return "input-method";
-	if (id_kind == GS_APP_ID_KIND_FONT)
-		return "font";
-	if (id_kind == GS_APP_ID_KIND_CODEC)
-		return "codec";
-	if (id_kind == GS_APP_ID_KIND_WEBAPP)
-		return "webapp";
-	return NULL;
-}
-
 /**
  * gs_app_to_string:
  **/
 gchar *
 gs_app_to_string (GsApp *app)
 {
+	AsImage *im;
+	AsScreenshot *ss;
 	GList *keys;
 	GList *l;
 	GString *str;
 	GsAppPrivate *priv = app->priv;
-	GsScreenshot *ss;
 	const gchar *tmp;
 	guint i;
 
@@ -220,12 +173,12 @@ gs_app_to_string (GsApp *app)
 	str = g_string_new ("GsApp:\n");
 	g_string_append_printf (str, "\tkind:\t%s\n",
 				gs_app_kind_to_string (priv->kind));
-	if (priv->id_kind != GS_APP_ID_KIND_UNKNOWN) {
+	if (priv->id_kind != AS_ID_KIND_UNKNOWN) {
 		g_string_append_printf (str, "\tid-kind:\t%s\n",
-					gs_app_id_kind_to_string (priv->id_kind));
+					as_id_kind_to_string (priv->id_kind));
 	}
 	g_string_append_printf (str, "\tstate:\t%s\n",
-				gs_app_state_to_string (priv->state));
+				as_app_state_to_string (priv->state));
 	if (priv->id_full != NULL)
 		g_string_append_printf (str, "\tid:\t%s\n", priv->id_full);
 	if ((priv->kudos & GS_APP_KUDO_MY_LANGUAGE) > 0)
@@ -252,6 +205,8 @@ gs_app_to_string (GsApp *app)
 		g_string_append (str, "\tkudo:\tpopular\n");
 	if ((priv->kudos & GS_APP_KUDO_IBUS_HAS_SYMBOL) > 0)
 		g_string_append (str, "\tkudo:\tibus-has-symbol\n");
+	if ((priv->kudos & GS_APP_KUDO_PERFECT_SCREENSHOTS) > 0)
+		g_string_append (str, "\tkudo:\tperfect-screenshots\n");
 	g_string_append_printf (str, "\tkudo-percentage:\t%i\n",
 				gs_app_get_kudos_percentage (app));
 	if (priv->name != NULL)
@@ -276,12 +231,12 @@ gs_app_to_string (GsApp *app)
 		g_string_append_printf (str, "\tdescription:\t%s\n", priv->description);
 	for (i = 0; i < priv->screenshots->len; i++) {
 		ss = g_ptr_array_index (priv->screenshots, i);
-		tmp = gs_screenshot_get_caption (ss);
+		tmp = as_screenshot_get_caption (ss, NULL);
+		im = as_screenshot_get_image (ss, 0, 0);
+		if (im == NULL)
+			continue;
 		g_string_append_printf (str, "\tscreenshot-%02i:\t%s [%s]\n",
-					i, gs_screenshot_get_url (ss,
-								  G_MAXUINT,
-								  G_MAXUINT,
-								  NULL),
+					i, as_image_get_url (im),
 					tmp != NULL ? tmp : "<none>");
 	}
 	for (i = 0; i < priv->sources->len; i++) {
@@ -292,7 +247,7 @@ gs_app_to_string (GsApp *app)
 		tmp = g_ptr_array_index (priv->source_ids, i);
 		g_string_append_printf (str, "\tsource-id-%02i:\t%s\n", i, tmp);
 	}
-	tmp = g_hash_table_lookup (priv->urls, GS_APP_URL_KIND_HOMEPAGE);
+	tmp = g_hash_table_lookup (priv->urls, as_url_kind_to_string (AS_URL_KIND_HOMEPAGE));
 	if (tmp != NULL)
 		g_string_append_printf (str, "\turl{homepage}:\t%s\n", tmp);
 	if (priv->licence != NULL)
@@ -423,10 +378,10 @@ gs_app_set_id (GsApp *app, const gchar *id)
 /**
  * gs_app_get_state:
  */
-GsAppState
+AsAppState
 gs_app_get_state (GsApp *app)
 {
-	g_return_val_if_fail (GS_IS_APP (app), GS_APP_STATE_UNKNOWN);
+	g_return_val_if_fail (GS_IS_APP (app), AS_APP_STATE_UNKNOWN);
 	return app->priv->state;
 }
 
@@ -434,7 +389,7 @@ gs_app_get_state (GsApp *app)
  * gs_app_set_state_internal:
  */
 static gboolean
-gs_app_set_state_internal (GsApp *app, GsAppState state)
+gs_app_set_state_internal (GsApp *app, AsAppState state)
 {
 	gboolean state_change_ok = FALSE;
 	GsAppPrivate *priv = app->priv;
@@ -444,70 +399,70 @@ gs_app_set_state_internal (GsApp *app, GsAppState state)
 
 	/* check the state change is allowed */
 	switch (priv->state) {
-	case GS_APP_STATE_UNKNOWN:
+	case AS_APP_STATE_UNKNOWN:
 		/* unknown has to go into one of the stable states */
-		if (state == GS_APP_STATE_INSTALLED ||
-		    state == GS_APP_STATE_QUEUED ||
-		    state == GS_APP_STATE_AVAILABLE ||
-		    state == GS_APP_STATE_LOCAL ||
-		    state == GS_APP_STATE_UPDATABLE ||
-		    state == GS_APP_STATE_UNAVAILABLE)
+		if (state == AS_APP_STATE_INSTALLED ||
+		    state == AS_APP_STATE_QUEUED_FOR_INSTALL ||
+		    state == AS_APP_STATE_AVAILABLE ||
+		    state == AS_APP_STATE_AVAILABLE_LOCAL ||
+		    state == AS_APP_STATE_UPDATABLE ||
+		    state == AS_APP_STATE_UNAVAILABLE)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_INSTALLED:
+	case AS_APP_STATE_INSTALLED:
 		/* installed has to go into an action state */
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_REMOVING)
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_REMOVING)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_QUEUED:
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_INSTALLING ||
-		    state == GS_APP_STATE_AVAILABLE)
+	case AS_APP_STATE_QUEUED_FOR_INSTALL:
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_INSTALLING ||
+		    state == AS_APP_STATE_AVAILABLE)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_AVAILABLE:
+	case AS_APP_STATE_AVAILABLE:
 		/* available has to go into an action state */
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_QUEUED ||
-		    state == GS_APP_STATE_INSTALLING)
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_QUEUED_FOR_INSTALL ||
+		    state == AS_APP_STATE_INSTALLING)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_INSTALLING:
+	case AS_APP_STATE_INSTALLING:
 		/* installing has to go into an stable state */
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_INSTALLED ||
-		    state == GS_APP_STATE_AVAILABLE)
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_INSTALLED ||
+		    state == AS_APP_STATE_AVAILABLE)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_REMOVING:
+	case AS_APP_STATE_REMOVING:
 		/* removing has to go into an stable state */
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_AVAILABLE ||
-		    state == GS_APP_STATE_INSTALLED)
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_AVAILABLE ||
+		    state == AS_APP_STATE_INSTALLED)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_UPDATABLE:
+	case AS_APP_STATE_UPDATABLE:
 		/* updatable has to go into an action state */
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_REMOVING)
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_REMOVING)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_UNAVAILABLE:
+	case AS_APP_STATE_UNAVAILABLE:
 		/* updatable has to go into an action state */
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_AVAILABLE)
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_AVAILABLE)
 			state_change_ok = TRUE;
 		break;
-	case GS_APP_STATE_LOCAL:
+	case AS_APP_STATE_AVAILABLE_LOCAL:
 		/* local has to go into an action state */
-		if (state == GS_APP_STATE_UNKNOWN ||
-		    state == GS_APP_STATE_INSTALLING)
+		if (state == AS_APP_STATE_UNKNOWN ||
+		    state == AS_APP_STATE_INSTALLING)
 			state_change_ok = TRUE;
 		break;
 	default:
 		g_warning ("state %s unhandled",
-			   gs_app_state_to_string (priv->state));
+			   as_app_state_to_string (priv->state));
 		g_assert_not_reached ();
 	}
 
@@ -515,16 +470,16 @@ gs_app_set_state_internal (GsApp *app, GsAppState state)
 	if (!state_change_ok) {
 		g_warning ("State change on %s from %s to %s is not OK",
 			   priv->id,
-			   gs_app_state_to_string (priv->state),
-			   gs_app_state_to_string (state));
+			   as_app_state_to_string (priv->state),
+			   as_app_state_to_string (state));
 		return FALSE;
 	}
 
 	priv->state = state;
 
-	if (state == GS_APP_STATE_UNKNOWN ||
-	    state == GS_APP_STATE_LOCAL ||
-	    state == GS_APP_STATE_AVAILABLE)
+	if (state == AS_APP_STATE_UNKNOWN ||
+	    state == AS_APP_STATE_AVAILABLE_LOCAL ||
+	    state == AS_APP_STATE_AVAILABLE)
 		app->priv->install_date = 0;
 
 	return TRUE;
@@ -534,7 +489,7 @@ gs_app_set_state_internal (GsApp *app, GsAppState state)
  * gs_app_set_state:
  *
  * This sets the state of the application. The following state diagram explains
- * the typical states. All applications start in state %GS_APP_STATE_UNKNOWN,
+ * the typical states. All applications start in state %AS_APP_STATE_UNKNOWN,
  * but the frontend is not supposed to see GsApps with this state, ever.
  * Backend plugins are reponsible for changing the state to one of the other
  * states before the GsApp is passed to the frontend. This is enforced by the
@@ -548,7 +503,7 @@ gs_app_set_state_internal (GsApp *app, GsAppState state)
  * UNKNOWN   --> UNAVAILABLE
  */
 void
-gs_app_set_state (GsApp *app, GsAppState state)
+gs_app_set_state (GsApp *app, AsAppState state)
 {
 	g_return_if_fail (GS_IS_APP (app));
 
@@ -635,7 +590,7 @@ gs_app_set_kind (GsApp *app, GsAppKind kind)
 /**
  * gs_app_get_id_kind:
  */
-GsAppIdKind
+AsIdKind
 gs_app_get_id_kind (GsApp *app)
 {
 	g_return_val_if_fail (GS_IS_APP (app), GS_APP_KIND_UNKNOWN);
@@ -646,7 +601,7 @@ gs_app_get_id_kind (GsApp *app)
  * gs_app_set_id_kind:
  */
 void
-gs_app_set_id_kind (GsApp *app, GsAppIdKind id_kind)
+gs_app_set_id_kind (GsApp *app, AsIdKind id_kind)
 {
 	g_return_if_fail (GS_IS_APP (app));
 	app->priv->id_kind = id_kind;
@@ -1132,23 +1087,21 @@ gs_app_set_description (GsApp *app, GsAppQuality quality, const gchar *descripti
  * gs_app_get_url:
  */
 const gchar *
-gs_app_get_url (GsApp *app, const gchar *kind)
+gs_app_get_url (GsApp *app, AsUrlKind kind)
 {
 	g_return_val_if_fail (GS_IS_APP (app), NULL);
-	return g_hash_table_lookup (app->priv->urls, kind);
+	return g_hash_table_lookup (app->priv->urls, as_url_kind_to_string (kind));
 }
 
 /**
  * gs_app_set_url:
- * @app:	A #GsApp instance
- * @summary:	The home page URL, e.g. "http://www.foo.com/gcalctool/"
  */
 void
-gs_app_set_url (GsApp *app, const gchar *kind, const gchar *url)
+gs_app_set_url (GsApp *app, AsUrlKind kind, const gchar *url)
 {
 	g_return_if_fail (GS_IS_APP (app));
 	g_hash_table_insert (app->priv->urls,
-			     g_strdup (kind),
+			     g_strdup (as_url_kind_to_string (kind)),
 			     g_strdup (url));
 }
 
@@ -1243,7 +1196,7 @@ gs_app_set_origin (GsApp *app, const gchar *origin)
  * gs_app_add_screenshot:
  */
 void
-gs_app_add_screenshot (GsApp *app, GsScreenshot *screenshot)
+gs_app_add_screenshot (GsApp *app, AsScreenshot *screenshot)
 {
 	g_return_if_fail (GS_IS_APP (app));
 	g_ptr_array_add (app->priv->screenshots, g_object_ref (screenshot));
@@ -1728,6 +1681,8 @@ gs_app_get_kudos_percentage (GsApp *app)
 		percentage += 20;
 	if ((app->priv->kudos & GS_APP_KUDO_IBUS_HAS_SYMBOL) > 0)
 		percentage += 20;
+	if ((app->priv->kudos & GS_APP_KUDO_PERFECT_SCREENSHOTS) > 0)
+		percentage += 20;
 
 	/* popular apps should be at *least* 50% */
 	if ((app->priv->kudos & GS_APP_KUDO_POPULAR) > 0)
@@ -1780,12 +1735,12 @@ gs_app_subsume (GsApp *app, GsApp *other)
 
 	/* an [updatable] installable package is more information than
 	 * just the fact that something is installed */
-	if (priv2->state == GS_APP_STATE_UPDATABLE &&
-	    priv->state == GS_APP_STATE_INSTALLED) {
+	if (priv2->state == AS_APP_STATE_UPDATABLE &&
+	    priv->state == AS_APP_STATE_INSTALLED) {
 		/* we have to do the little dance to appease the
 		 * angry gnome controlling the state-machine */
-		gs_app_set_state_internal (app, GS_APP_STATE_UNKNOWN);
-		gs_app_set_state_internal (app, GS_APP_STATE_UPDATABLE);
+		gs_app_set_state_internal (app, AS_APP_STATE_UNKNOWN);
+		gs_app_set_state_internal (app, AS_APP_STATE_UPDATABLE);
 	}
 
 	/* save any properties we already know */
@@ -1993,9 +1948,9 @@ gs_app_class_init (GsAppClass *klass)
 	 * GsApp:state:
 	 */
 	pspec = g_param_spec_uint ("state", NULL, NULL,
-				   GS_APP_STATE_UNKNOWN,
-				   GS_APP_STATE_LAST,
-				   GS_APP_STATE_UNKNOWN,
+				   AS_APP_STATE_UNKNOWN,
+				   AS_APP_STATE_LAST,
+				   AS_APP_STATE_UNKNOWN,
 				   G_PARAM_READWRITE | G_PARAM_CONSTRUCT);
 	g_object_class_install_property (object_class, PROP_STATE, pspec);
 
