@@ -24,8 +24,7 @@
 
 #include <glib-object.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
-
-#include "gs-screenshot.h"
+#include <appstream-glib.h>
 
 G_BEGIN_DECLS
 
@@ -67,30 +66,6 @@ typedef enum {
 	GS_APP_KIND_LAST
 } GsAppKind;
 
-typedef enum {
-	GS_APP_STATE_UNKNOWN,
-	GS_APP_STATE_INSTALLED,
-	GS_APP_STATE_AVAILABLE,
-	GS_APP_STATE_QUEUED,
-	GS_APP_STATE_INSTALLING,
-	GS_APP_STATE_REMOVING,
-	GS_APP_STATE_UPDATABLE,
-	GS_APP_STATE_UNAVAILABLE,	/* we found a reference to this */
-	GS_APP_STATE_LOCAL,
-	GS_APP_STATE_LAST
-} GsAppState;
-
-typedef enum {
-	GS_APP_ID_KIND_UNKNOWN,
-	GS_APP_ID_KIND_DESKTOP,
-	GS_APP_ID_KIND_INPUT_METHOD,
-	GS_APP_ID_KIND_FONT,
-	GS_APP_ID_KIND_CODEC,
-	GS_APP_ID_KIND_WEBAPP,
-	GS_APP_ID_KIND_ADDON,
-	GS_APP_ID_KIND_LAST
-} GsAppIdKind;
-
 typedef enum {
 	GS_APP_RATING_KIND_UNKNOWN,
 	GS_APP_RATING_KIND_USER,
@@ -112,6 +87,7 @@ typedef enum {
 	GS_APP_KUDO_HAS_SCREENSHOTS		= 1 << 9,
 	GS_APP_KUDO_POPULAR			= 1 << 10,
 	GS_APP_KUDO_IBUS_HAS_SYMBOL		= 1 << 11,
+	GS_APP_KUDO_PERFECT_SCREENSHOTS		= 1 << 12,
 	GS_APP_KUDO_LAST
 } GsAppKudo;
 
@@ -120,9 +96,6 @@ typedef enum {
 #define	GS_APP_SIZE_UNKNOWN			0
 #define	GS_APP_SIZE_MISSING			1
 
-#define	GS_APP_URL_KIND_HOMEPAGE		"homepage"
-#define	GS_APP_URL_KIND_MISSING			"missing"
-
 typedef enum {
 	GS_APP_QUALITY_UNKNOWN,
 	GS_APP_QUALITY_LOWEST,
@@ -139,8 +112,6 @@ GType		 gs_app_get_type		(void);
 GsApp		*gs_app_new			(const gchar	*id);
 gchar		*gs_app_to_string		(GsApp		*app);
 const gchar	*gs_app_kind_to_string		(GsAppKind	 kind);
-const gchar	*gs_app_id_kind_to_string	(GsAppIdKind	 id_kind);
-const gchar	*gs_app_state_to_string		(GsAppState	 state);
 
 void		 gs_app_subsume			(GsApp		*app,
 						 GsApp		*other);
@@ -152,12 +123,12 @@ void		 gs_app_set_id			(GsApp		*app,
 GsAppKind	 gs_app_get_kind		(GsApp		*app);
 void		 gs_app_set_kind		(GsApp		*app,
 						 GsAppKind	 kind);
-GsAppIdKind	 gs_app_get_id_kind		(GsApp		*app);
+AsIdKind	 gs_app_get_id_kind		(GsApp		*app);
 void		 gs_app_set_id_kind		(GsApp		*app,
-						 GsAppIdKind	 id_kind);
-GsAppState	 gs_app_get_state		(GsApp		*app);
+						 AsIdKind	 id_kind);
+AsAppState	 gs_app_get_state		(GsApp		*app);
 void		 gs_app_set_state		(GsApp		*app,
-						 GsAppState	 state);
+						 AsAppState	 state);
 const gchar	*gs_app_get_name		(GsApp		*app);
 void		 gs_app_set_name		(GsApp		*app,
 						 GsAppQuality	 quality,
@@ -193,9 +164,9 @@ void		 gs_app_set_description		(GsApp		*app,
 						 GsAppQuality	 quality,
 						 const gchar	*description);
 const gchar	*gs_app_get_url			(GsApp		*app,
-						 const gchar	*kind);
+						 AsUrlKind	 kind);
 void		 gs_app_set_url			(GsApp		*app,
-						 const gchar	*kind,
+						 AsUrlKind	 kind,
 						 const gchar	*url);
 const gchar	*gs_app_get_licence		(GsApp		*app);
 void		 gs_app_set_licence		(GsApp		*app,
@@ -208,7 +179,7 @@ void		 gs_app_set_origin		(GsApp		*app,
 						 const gchar	*origin);
 GPtrArray	*gs_app_get_screenshots		(GsApp		*app);
 void		 gs_app_add_screenshot		(GsApp		*app,
-						 GsScreenshot	*screenshot);
+						 AsScreenshot	*screenshot);
 const gchar	*gs_app_get_update_version	(GsApp		*app);
 const gchar	*gs_app_get_update_version_ui	(GsApp		*app);
 void		 gs_app_set_update_version	(GsApp		*app,
