@@ -31,6 +31,7 @@
 
 #include "gs-dbus-helper.h"
 #include "gs-box.h"
+#include "gs-first-run-dialog.h"
 #include "gs-shell.h"
 #include "gs-update-monitor.h"
 #include "gs-proxy-settings.h"
@@ -164,13 +165,26 @@ gs_application_provide_search (GsApplication *app)
 					app->plugin_loader);
 }
 
+static void
+gs_application_show_first_run_dialog (GsApplication *app)
+{
+	GtkWidget *dialog;
+
+	if (g_settings_get_boolean (app->settings, "first-run") == TRUE) {
+		dialog = gs_first_run_dialog_new ();
+		gtk_window_set_transient_for (GTK_WINDOW (dialog), gs_shell_get_window (app->shell));
+		gtk_window_present (GTK_WINDOW (dialog));
+
+		g_settings_set_boolean (app->settings, "first-run", FALSE);
+	}
+}
+
 static void
 gs_application_initialize_ui (GsApplication *app)
 {
 	static gboolean initialized = FALSE;
 	GtkBuilder *builder;
 	GMenuModel *app_menu;
-	GtkWindow *window;
 	GFile *file;
 	gchar *theme;
 
@@ -209,11 +223,11 @@ gs_application_initialize_ui (GsApplication *app)
 
 	app->cancellable = g_cancellable_new ();
 
-	window = gs_shell_setup (app->shell, app->plugin_loader, app->cancellable);
-	gtk_application_add_window (GTK_APPLICATION (app), window);
+	gs_shell_setup (app->shell, app->plugin_loader, app->cancellable);
+	gtk_application_add_window (GTK_APPLICATION (app), gs_shell_get_window (app->shell));
 
 	g_signal_connect_swapped (app->shell, "loaded",
-				  G_CALLBACK (gtk_window_present), window);
+				  G_CALLBACK (gtk_window_present), gs_shell_get_window (app->shell));
 }
 
 static void
@@ -478,6 +492,7 @@ gs_application_activate (GApplication *application)
 	gs_application_initialize_ui (GS_APPLICATION (application));
 	gs_shell_set_mode (GS_APPLICATION (application)->shell, GS_SHELL_MODE_OVERVIEW);
 	gs_shell_activate (GS_APPLICATION (application)->shell);
+	gs_application_show_first_run_dialog (GS_APPLICATION (application));
 }
 
 static void
@@ -514,6 +529,7 @@ gs_application_local_command_line (GApplication *app, gchar ***args, gint *statu
 	gchar *local_filename = NULL;
 	gchar *id = NULL;
 	gboolean activate_ui = TRUE;
+	gboolean prefer_local = FALSE;
 	gboolean version = FALSE;
 	gboolean profile = FALSE;
 	gboolean verbose = FALSE;
@@ -534,6 +550,8 @@ gs_application_local_command_line (GApplication *app, gchar ***args, gint *statu
 		  _("Set the specified debugging level"), _("ID") },
 		{ "profile", 0, 0, G_OPTION_ARG_NONE, &profile,
 		  _("Show profiling information for the service"), NULL },
+		{ "prefer-local", '\0', 0, G_OPTION_ARG_NONE, &prefer_local,
+		  _("Prefer local file sources to AppStream"), NULL },
 		{ "version", 0, 0, G_OPTION_ARG_NONE, &version, NULL, NULL },
 		{ NULL}
 	};
@@ -553,6 +571,10 @@ gs_application_local_command_line (GApplication *app, gchar ***args, gint *statu
 	if (verbose)
 		g_setenv ("G_MESSAGES_DEBUG", "all", TRUE);
 
+	/* prefer local sources */
+	if (prefer_local)
+		g_setenv ("GNOME_SOFTWARE_PREFER_LOCAL", "true", TRUE);
+
 	if (version) {
 		g_print ("gnome-software " VERSION "\n");
 		*status = 0;
