@@ -54,6 +54,8 @@ GsCategory	*gs_category_new		(GsCategory	*parent,
 						 const gchar	*name);
 const gchar	*gs_category_get_id		(GsCategory	*category);
 GsCategory      *gs_category_get_parent		(GsCategory	*category);
+GsCategory	*gs_category_find_child		(GsCategory	*category,
+						 const gchar	*id);
 const gchar	*gs_category_get_name		(GsCategory	*category);
 void		 gs_category_set_name		(GsCategory	*category,
 						 const gchar	*name);
