@@ -25,11 +25,15 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
+#define GNOME_DESKTOP_USE_UNSTABLE_API
+#include <libgnome-desktop/gnome-bg.h>
+#include <libgnome-desktop/gnome-desktop-thumbnail.h>
+
 #include "gs-screenshot-image.h"
 
 struct _GsScreenshotImagePrivate
 {
-	GsScreenshot	*screenshot;
+	AsScreenshot	*screenshot;
 	GtkWidget	*stack;
 	GtkWidget	*box_error;
 	GtkWidget	*image1;
@@ -48,7 +52,7 @@ G_DEFINE_TYPE_WITH_PRIVATE (GsScreenshotImage, gs_screenshot_image, GTK_TYPE_BIN
 /**
  * gs_screenshot_image_get_screenshot:
  **/
-GsScreenshot *
+AsScreenshot *
 gs_screenshot_image_get_screenshot (GsScreenshotImage *ssimg)
 {
 	GsScreenshotImagePrivate *priv;
@@ -90,24 +94,102 @@ gs_screenshot_image_set_error (GsScreenshotImage *ssimg, const gchar *message)
 }
 
 /**
- * gs_screenshot_show_image:
+ * gs_screenshot_image_get_desktop_pixbuf:
+ **/
+static GdkPixbuf *
+gs_screenshot_image_get_desktop_pixbuf (GsScreenshotImage *ssimg)
+{
+	GdkPixbuf *pixbuf;
+	GnomeBG *bg;
+	GnomeDesktopThumbnailFactory *factory;
+	GSettings *settings;
+	GsScreenshotImagePrivate *priv;
+
+	priv = gs_screenshot_image_get_instance_private (ssimg);
+
+	factory = gnome_desktop_thumbnail_factory_new (GNOME_DESKTOP_THUMBNAIL_SIZE_LARGE);
+	bg = gnome_bg_new ();
+	settings = g_settings_new ("org.gnome.desktop.background");
+	gnome_bg_load_from_preferences (bg, settings);
+	pixbuf = gnome_bg_create_thumbnail (bg, factory, gdk_screen_get_default (), priv->width, priv->height);
+	g_object_unref (bg);
+	g_object_unref (factory);
+	g_object_unref (settings);
+	return pixbuf;
+}
+
+/**
+ * gs_screenshot_image_use_desktop_background:
+ **/
+static gboolean
+gs_screenshot_image_use_desktop_background (GdkPixbuf *pixbuf)
+{
+	AsImage *im;
+	gboolean ret;
+
+	/* nothing to show, means no background mode */
+	if (pixbuf == NULL)
+		return FALSE;
+
+	/* use a temp AsImage */
+	im = as_image_new ();
+	as_image_set_pixbuf (im, pixbuf);
+	ret = (as_image_get_alpha_flags (im) & AS_IMAGE_ALPHA_FLAG_INTERNAL) > 0;
+	g_object_unref (im);
+	return ret;
+}
+
+/**
+ * as_screenshot_show_image:
  **/
 static void
-gs_screenshot_show_image (GsScreenshotImage *ssimg)
+as_screenshot_show_image (GsScreenshotImage *ssimg)
 {
+	GdkPixbuf *pixbuf_bg = NULL;
+	GdkPixbuf *pixbuf = NULL;
 	GsScreenshotImagePrivate *priv;
+
 	priv = gs_screenshot_image_get_instance_private (ssimg);
 
+	/* this is always going to have alpha */
+	pixbuf = gdk_pixbuf_new_from_file_at_scale (priv->filename,
+						    priv->width,
+						    priv->height,
+						    FALSE, NULL);
+	if (pixbuf != NULL) {
+		if (gs_screenshot_image_use_desktop_background (pixbuf)) {
+			pixbuf_bg = gs_screenshot_image_get_desktop_pixbuf (ssimg);
+			if (pixbuf_bg == NULL) {
+				pixbuf_bg = g_object_ref (pixbuf);
+			} else {
+				gdk_pixbuf_composite (pixbuf, pixbuf_bg,
+						      0, 0,
+						      priv->width, priv->height,
+						      0, 0, 1.0f, 1.0f,
+						      GDK_INTERP_NEAREST, 255);
+			}
+		} else {
+			pixbuf_bg = g_object_ref (pixbuf);
+		}
+	}
+
 	/* show icon */
 	if (g_strcmp0 (priv->current_image, "image1") == 0) {
-		gtk_image_set_from_file (GTK_IMAGE (priv->image2), priv->filename);
+		if (pixbuf_bg != NULL)
+			gtk_image_set_from_pixbuf (GTK_IMAGE (priv->image2), pixbuf_bg);
 		gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "image2");
 		priv->current_image = "image2";
 	} else {
-		gtk_image_set_from_file (GTK_IMAGE (priv->image1), priv->filename);
+		if (pixbuf_bg != NULL)
+			gtk_image_set_from_pixbuf (GTK_IMAGE (priv->image1), pixbuf_bg);
 		gtk_stack_set_visible_child_name (GTK_STACK (priv->stack), "image1");
 		priv->current_image = "image1";
 	}
+
+	if (pixbuf != NULL)
+		g_object_unref (pixbuf);
+	if (pixbuf_bg != NULL)
+		g_object_unref (pixbuf_bg);
 	gtk_widget_show (GTK_WIDGET (ssimg));
 }
 
@@ -119,10 +201,13 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 				 SoupMessage *msg,
 				 gpointer user_data)
 {
+	AsImage *im = NULL;
 	GsScreenshotImagePrivate *priv;
 	GsScreenshotImage *ssimg = GS_SCREENSHOT_IMAGE (user_data);
-	gboolean ret;
 	GError *error = NULL;
+	GdkPixbuf *pixbuf = NULL;
+	GInputStream *stream = NULL;
+	gboolean ret;
 
 	if (msg->status_code != SOUP_STATUS_OK) {
 		/* TRANSLATORS: this is when we try to download a screenshot and
@@ -134,11 +219,28 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 
 	priv = gs_screenshot_image_get_instance_private (ssimg);
 
-	/* save to file */
-	ret = g_file_set_contents (priv->filename,
-				   msg->response_body->data,
-				   msg->response_body->length,
-				   &error);
+	/* create a buffer with the data */
+	stream = g_memory_input_stream_new_from_data (msg->response_body->data,
+						      msg->response_body->length,
+						      NULL);
+	if (stream == NULL)
+		goto out;
+
+	/* load the image */
+	pixbuf = gdk_pixbuf_new_from_stream (stream, NULL, NULL);
+	if (pixbuf == NULL) {
+		/* TRANSLATORS: possibly image file corrupt or not an image */
+		gs_screenshot_image_set_error (ssimg, _("Failed to load image"));
+		goto out;
+	}
+
+	/* save to file, using the same code as the AppStream builder so the
+	 * preview looks the same */
+	im = as_image_new ();
+	as_image_set_pixbuf (im, pixbuf);
+	ret = as_image_save_filename (im, priv->filename,
+				      priv->width, priv->height,
+				      AS_IMAGE_SAVE_FLAG_PAD_16_9, &error);
 	if (!ret) {
 		gs_screenshot_image_set_error (ssimg, error->message);
 		g_error_free (error);
@@ -146,8 +248,14 @@ gs_screenshot_image_complete_cb (SoupSession *session,
 	}
 
 	/* got image, so show */
-	gs_screenshot_show_image (ssimg);
+	as_screenshot_show_image (ssimg);
 out:
+	if (stream != NULL)
+		g_object_unref (stream);
+	if (pixbuf != NULL)
+		g_object_unref (pixbuf);
+	if (im != NULL)
+		g_object_unref (im);
 	g_object_unref (ssimg);
 }
 
@@ -168,12 +276,12 @@ gs_screenshot_image_set_cachedir (GsScreenshotImage *ssimg, const gchar *cachedi
  **/
 void
 gs_screenshot_image_set_screenshot (GsScreenshotImage *ssimg,
-				    GsScreenshot *screenshot)
+				    AsScreenshot *screenshot)
 {
 	GsScreenshotImagePrivate *priv;
 
 	g_return_if_fail (GS_IS_SCREENSHOT_IMAGE (ssimg));
-	g_return_if_fail (GS_IS_SCREENSHOT (screenshot));
+	g_return_if_fail (AS_IS_SCREENSHOT (screenshot));
 
 	priv = gs_screenshot_image_get_instance_private (ssimg);
 
@@ -210,6 +318,7 @@ void
 gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 				GCancellable *cancellable)
 {
+	AsImage *im;
 	GsScreenshotImagePrivate *priv;
 	SoupMessage *msg = NULL;
 	SoupURI *base_uri = NULL;
@@ -223,21 +332,21 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 
 	priv = gs_screenshot_image_get_instance_private (ssimg);
 
-	g_return_if_fail (GS_IS_SCREENSHOT (priv->screenshot));
+	g_return_if_fail (AS_IS_SCREENSHOT (priv->screenshot));
 	g_return_if_fail (priv->width != 0);
 	g_return_if_fail (priv->height != 0);
 
 	/* test if size specific cachdir exists */
-	url = gs_screenshot_get_url (priv->screenshot,
-				     priv->width,
-				     priv->height,
-				     NULL);
-	if (url == NULL) {
+	im = as_screenshot_get_image (priv->screenshot,
+				      priv->width,
+				      priv->height);
+	if (im == NULL) {
 		/* TRANSLATORS: this is when we request a screenshot size that
 		 * the generator did not create or the parser did not add */
 		gs_screenshot_image_set_error (ssimg, _("Screenshot size not found"));
 		goto out;
 	}
+	url = as_image_get_url (im);
 	basename = g_path_get_basename (url);
 	sizedir = g_strdup_printf ("%ux%u", priv->width, priv->height);
 	cachedir = g_build_filename (priv->cachedir,
@@ -256,7 +365,7 @@ gs_screenshot_image_load_async (GsScreenshotImage *ssimg,
 	/* does local file already exist */
 	priv->filename = g_build_filename (cachedir, basename, NULL);
 	if (g_file_test (priv->filename, G_FILE_TEST_EXISTS)) {
-		gs_screenshot_show_image (ssimg);
+		as_screenshot_show_image (ssimg);
 		goto out;
 	}
 
