@@ -25,6 +25,7 @@
 #include <string.h>
 #include <glib/gi18n.h>
 #include <gio/gdesktopappinfo.h>
+#include <appstream-glib.h>
 
 #include "gs-utils.h"
 
@@ -142,7 +143,7 @@ gs_shell_details_refresh (GsShellDetails *shell_details)
 {
 	GsShellDetailsPrivate *priv = shell_details->priv;
 	GsAppKind kind;
-	GsAppState state;
+	AsAppState state;
 	GtkWidget *widget;
 	GtkAdjustment *adj;
 
@@ -160,7 +161,7 @@ gs_shell_details_refresh (GsShellDetails *shell_details)
 	/* label */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "header_label"));
 	switch (state) {
-	case GS_APP_STATE_QUEUED:
+	case AS_APP_STATE_QUEUED_FOR_INSTALL:
 		gtk_widget_set_visible (widget, TRUE);
 		gtk_label_set_label (GTK_LABEL (widget), _("Pending"));
 		break;
@@ -172,8 +173,8 @@ gs_shell_details_refresh (GsShellDetails *shell_details)
 	/* install button */
 	widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_install"));
 	switch (state) {
-	case GS_APP_STATE_AVAILABLE:
-	case GS_APP_STATE_LOCAL:
+	case AS_APP_STATE_AVAILABLE:
+	case AS_APP_STATE_AVAILABLE_LOCAL:
 		gtk_widget_set_visible (widget, gs_app_get_kind (priv->app) != GS_APP_KIND_CORE);
 		gtk_widget_set_sensitive (widget, TRUE);
 		gtk_style_context_add_class (gtk_widget_get_style_context (widget), "suggested-action");
@@ -181,10 +182,10 @@ gs_shell_details_refresh (GsShellDetails *shell_details)
 		 * can be installed */
 		gtk_button_set_label (GTK_BUTTON (widget), _("_Install"));
 		break;
-	case GS_APP_STATE_QUEUED:
+	case AS_APP_STATE_QUEUED_FOR_INSTALL:
 		gtk_widget_set_visible (widget, FALSE);
 		break;
-	case GS_APP_STATE_INSTALLING:
+	case AS_APP_STATE_INSTALLING:
 		gtk_widget_set_visible (widget, TRUE);
 		gtk_widget_set_sensitive (widget, FALSE);
 		gtk_style_context_remove_class (gtk_widget_get_style_context (widget), "suggested-action");
@@ -192,16 +193,16 @@ gs_shell_details_refresh (GsShellDetails *shell_details)
 		 * is in the process of being installed */
 		gtk_button_set_label (GTK_BUTTON (widget), _("_Installing"));
 		break;
-	case GS_APP_STATE_UNKNOWN:
-	case GS_APP_STATE_INSTALLED:
-	case GS_APP_STATE_REMOVING:
-	case GS_APP_STATE_UPDATABLE:
-	case GS_APP_STATE_UNAVAILABLE:
+	case AS_APP_STATE_UNKNOWN:
+	case AS_APP_STATE_INSTALLED:
+	case AS_APP_STATE_REMOVING:
+	case AS_APP_STATE_UPDATABLE:
+	case AS_APP_STATE_UNAVAILABLE:
 		gtk_widget_set_visible (widget, FALSE);
 		break;
 	default:
 		g_warning ("App unexpectedly in state %s",
-			   gs_app_state_to_string (state));
+			   as_app_state_to_string (state));
 		g_assert_not_reached ();
 	}
 
@@ -211,37 +212,37 @@ gs_shell_details_refresh (GsShellDetails *shell_details)
 		gtk_widget_set_visible (widget, FALSE);
 	} else {
 		switch (state) {
-		case GS_APP_STATE_INSTALLED:
-		case GS_APP_STATE_UPDATABLE:
+		case AS_APP_STATE_INSTALLED:
+		case AS_APP_STATE_UPDATABLE:
 			gtk_widget_set_visible (widget, TRUE);
 			gtk_widget_set_sensitive (widget, TRUE);
 			gtk_style_context_add_class (gtk_widget_get_style_context (widget), "destructive-action");
 			/* TRANSLATORS: button text in the header when an application can be erased */
 			gtk_button_set_label (GTK_BUTTON (widget), _("_Remove"));
 			break;
-		case GS_APP_STATE_REMOVING:
+		case AS_APP_STATE_REMOVING:
 			gtk_widget_set_visible (widget, TRUE);
 			gtk_widget_set_sensitive (widget, FALSE);
 			gtk_style_context_remove_class (gtk_widget_get_style_context (widget), "destructive-action");
 			/* TRANSLATORS: button text in the header when an application can be installed */
 			gtk_button_set_label (GTK_BUTTON (widget), _("_Removing"));
 			break;
-		case GS_APP_STATE_QUEUED:
+		case AS_APP_STATE_QUEUED_FOR_INSTALL:
 			gtk_widget_set_visible (widget, TRUE);
 			gtk_widget_set_sensitive (widget, TRUE);
 			gtk_style_context_remove_class (gtk_widget_get_style_context (widget), "destructive-action");
 			gtk_button_set_label (GTK_BUTTON (widget), _("_Cancel"));
 			break;
-		case GS_APP_STATE_LOCAL:
-		case GS_APP_STATE_AVAILABLE:
-		case GS_APP_STATE_INSTALLING:
-		case GS_APP_STATE_UNAVAILABLE:
-		case GS_APP_STATE_UNKNOWN:
+		case AS_APP_STATE_AVAILABLE_LOCAL:
+		case AS_APP_STATE_AVAILABLE:
+		case AS_APP_STATE_INSTALLING:
+		case AS_APP_STATE_UNAVAILABLE:
+		case AS_APP_STATE_UNKNOWN:
 			gtk_widget_set_visible (widget, FALSE);
 			break;
 		default:
 			g_warning ("App unexpectedly in state %s",
-				   gs_app_state_to_string (state));
+				   as_app_state_to_string (state));
 			g_assert_not_reached ();
 		}
 	}
@@ -253,24 +254,24 @@ gs_shell_details_refresh (GsShellDetails *shell_details)
 		gtk_spinner_stop (GTK_SPINNER (widget));
 	} else {
 		switch (state) {
-		case GS_APP_STATE_UNKNOWN:
-		case GS_APP_STATE_INSTALLED:
-		case GS_APP_STATE_AVAILABLE:
-		case GS_APP_STATE_QUEUED:
-		case GS_APP_STATE_UPDATABLE:
-		case GS_APP_STATE_UNAVAILABLE:
-		case GS_APP_STATE_LOCAL:
+		case AS_APP_STATE_UNKNOWN:
+		case AS_APP_STATE_INSTALLED:
+		case AS_APP_STATE_AVAILABLE:
+		case AS_APP_STATE_QUEUED_FOR_INSTALL:
+		case AS_APP_STATE_UPDATABLE:
+		case AS_APP_STATE_UNAVAILABLE:
+		case AS_APP_STATE_AVAILABLE_LOCAL:
 			gtk_widget_set_visible (widget, FALSE);
 			gtk_spinner_stop (GTK_SPINNER (widget));
 			break;
-		case GS_APP_STATE_INSTALLING:
-		case GS_APP_STATE_REMOVING:
+		case AS_APP_STATE_INSTALLING:
+		case AS_APP_STATE_REMOVING:
 			gtk_spinner_start (GTK_SPINNER (widget));
 			gtk_widget_set_visible (widget, TRUE);
 			break;
 		default:
 			g_warning ("App unexpectedly in state %s",
-				   gs_app_state_to_string (state));
+				   as_app_state_to_string (state));
 			g_assert_not_reached ();
 		}
 	}
@@ -300,7 +301,7 @@ gs_shell_details_screenshot_selected_cb (GtkListBox *list,
 	GsShellDetailsPrivate *priv = shell_details->priv;
 	GsScreenshotImage *ssmain;
 	GsScreenshotImage *ssthumb;
-	GsScreenshot *ss;
+	AsScreenshot *ss;
 	GList *children;
 
 	if (row == NULL)
@@ -323,16 +324,15 @@ static void
 gs_shell_details_refresh_screenshots (GsShellDetails *shell_details)
 {
 	GPtrArray *screenshots;
-	GsScreenshot *ss;
+	AsScreenshot *ss;
 	GsShellDetailsPrivate *priv = shell_details->priv;
 	GtkWidget *label;
 	GtkWidget *list;
 	GtkWidget *ssimg;
 	guint i;
-	GtkRequisition provided;
 
 	/* treat screenshots differently */
-	if (gs_app_get_id_kind (priv->app) == GS_APP_ID_KIND_FONT) {
+	if (gs_app_get_id_kind (priv->app) == AS_ID_KIND_FONT) {
 		gs_container_remove_all (GTK_CONTAINER (priv->box_details_screenshot_thumbnails));
 		gs_container_remove_all (GTK_CONTAINER (priv->box_details_screenshot_main));
 		screenshots = gs_app_get_screenshots (priv->app);
@@ -340,7 +340,7 @@ gs_shell_details_refresh_screenshots (GsShellDetails *shell_details)
 			ss = g_ptr_array_index (screenshots, i);
 
 			/* set caption */
-			label = gtk_label_new (gs_screenshot_get_caption (ss));
+			label = gtk_label_new (as_screenshot_get_caption (ss, NULL));
 			g_object_set (label,
 				      "xalign", 0.0,
 				      NULL);
@@ -381,19 +381,14 @@ gs_shell_details_refresh_screenshots (GsShellDetails *shell_details)
 
 	/* use a slightly larger screenshot if it's the only screenshot */
 	if (screenshots->len == 1) {
-		gs_screenshot_get_url (ss,
-				       GS_SCREENSHOT_SIZE_MAIN_ONLY_WIDTH,
-				       GS_SCREENSHOT_SIZE_MAIN_ONLY_HEIGHT,
-				       &provided);
+		gs_screenshot_image_set_size (GS_SCREENSHOT_IMAGE (ssimg),
+					      AS_IMAGE_LARGE_WIDTH,
+					      AS_IMAGE_LARGE_HEIGHT);
 	} else {
-		gs_screenshot_get_url (ss,
-				       GS_SCREENSHOT_SIZE_MAIN_WIDTH,
-				       GS_SCREENSHOT_SIZE_MAIN_HEIGHT,
-				       &provided);
+		gs_screenshot_image_set_size (GS_SCREENSHOT_IMAGE (ssimg),
+					      AS_IMAGE_NORMAL_WIDTH,
+					      AS_IMAGE_NORMAL_HEIGHT);
 	}
-	gs_screenshot_image_set_size (GS_SCREENSHOT_IMAGE (ssimg),
-				      provided.width, provided.height);
-
 	gs_screenshot_image_load_async (GS_SCREENSHOT_IMAGE (ssimg), NULL);
 	gtk_box_pack_start (GTK_BOX (priv->box_details_screenshot_main), ssimg, FALSE, FALSE, 0);
 	gtk_widget_set_visible (ssimg, TRUE);
@@ -414,8 +409,8 @@ gs_shell_details_refresh_screenshots (GsShellDetails *shell_details)
 						  g_get_user_cache_dir ());
 		gs_screenshot_image_set_screenshot (GS_SCREENSHOT_IMAGE (ssimg), ss);
 		gs_screenshot_image_set_size (GS_SCREENSHOT_IMAGE (ssimg),
-					      GS_SCREENSHOT_SIZE_THUMBNAIL_WIDTH,
-					      GS_SCREENSHOT_SIZE_THUMBNAIL_HEIGHT);
+					      AS_IMAGE_THUMBNAIL_WIDTH,
+					      AS_IMAGE_THUMBNAIL_HEIGHT);
 		gtk_style_context_add_class (gtk_widget_get_style_context (ssimg),
 					     "screenshot-image-thumb");
 		gs_screenshot_image_load_async (GS_SCREENSHOT_IMAGE (ssimg), NULL);
@@ -442,7 +437,7 @@ gs_shell_details_website_cb (GtkWidget *widget, GsShellDetails *shell_details)
 	const gchar *url;
 	gboolean ret;
 
-	url = gs_app_get_url (priv->app, GS_APP_URL_KIND_HOMEPAGE);
+	url = gs_app_get_url (priv->app, AS_URL_KIND_HOMEPAGE);
 	ret = gtk_show_uri (NULL, url, GDK_CURRENT_TIME, &error);
 	if (!ret) {
 		g_warning ("spawn of '%s' failed", url);
@@ -499,11 +494,11 @@ out:
 static gboolean
 gs_shell_details_is_addon_id_kind (GsApp *app)
 {
-        GsAppIdKind id_kind;
+        AsIdKind id_kind;
         id_kind = gs_app_get_id_kind (app);
-        if (id_kind == GS_APP_ID_KIND_DESKTOP)
+        if (id_kind == AS_ID_KIND_DESKTOP)
                 return FALSE;
-        if (id_kind == GS_APP_ID_KIND_WEBAPP)
+        if (id_kind == AS_ID_KIND_WEB_APP)
                 return FALSE;
         return TRUE;
 }
@@ -559,7 +554,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	}
 	if (pixbuf == NULL)
 		pixbuf = gs_app_get_pixbuf (priv->app);
-	if (pixbuf == NULL && gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL) {
+	if (pixbuf == NULL && gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL) {
 		if (gs_app_get_kind (priv->app) == GS_APP_KIND_SOURCE)
 			pixbuf = gs_pixbuf_load ("x-package-repository", 96, NULL);
 		else if (gs_shell_details_is_addon_id_kind (priv->app))
@@ -574,7 +569,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 		gtk_widget_set_visible (priv->application_details_icon, FALSE);
 	}
 
-	tmp = gs_app_get_url (priv->app, GS_APP_URL_KIND_HOMEPAGE);
+	tmp = gs_app_get_url (priv->app, AS_URL_KIND_HOMEPAGE);
 	if (tmp != NULL && tmp[0] != '\0') {
 		gtk_widget_set_visible (priv->button_details_website, TRUE);
 	} else {
@@ -660,15 +655,15 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 		gtk_label_set_label (GTK_LABEL (priv->label_details_origin_value), tmp);
 	}
 	gtk_widget_set_visible (priv->label_details_origin_value,
-				gs_app_get_state (priv->app) == GS_APP_STATE_INSTALLED ||
-				gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL);
+				gs_app_get_state (priv->app) == AS_APP_STATE_INSTALLED ||
+				gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 	gtk_widget_set_visible (priv->label_details_origin_title,
-				gs_app_get_state (priv->app) == GS_APP_STATE_INSTALLED ||
-				gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL);
+				gs_app_get_state (priv->app) == AS_APP_STATE_INSTALLED ||
+				gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 
 	/* set the rating */
 	switch (gs_app_get_id_kind (priv->app)) {
-	case GS_APP_ID_KIND_WEBAPP:
+	case AS_ID_KIND_WEB_APP:
 		gtk_widget_set_visible (priv->star, FALSE);
 		break;
 	default:
@@ -686,20 +681,20 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	}
 
 	/* don't show a missing rating on a local file */
-	if (gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL &&
+	if (gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL &&
 	    gs_app_get_rating (priv->app) < 0)
 		gtk_widget_set_visible (priv->star, FALSE);
 
 	/* only mark the stars as sensitive if the application is installed */
 	gtk_widget_set_sensitive (priv->star,
-				  gs_app_get_state (priv->app) == GS_APP_STATE_INSTALLED);
+				  gs_app_get_state (priv->app) == AS_APP_STATE_INSTALLED);
 
 	/* only show launch button when the application is installed */
 	switch (gs_app_get_state (priv->app)) {
-	case GS_APP_STATE_INSTALLED:
-	case GS_APP_STATE_UPDATABLE:
-		if (gs_app_get_id_kind (priv->app) == GS_APP_ID_KIND_DESKTOP ||
-		    gs_app_get_id_kind (priv->app) == GS_APP_ID_KIND_WEBAPP) {
+	case AS_APP_STATE_INSTALLED:
+	case AS_APP_STATE_UPDATABLE:
+		if (gs_app_get_id_kind (priv->app) == AS_ID_KIND_DESKTOP ||
+		    gs_app_get_id_kind (priv->app) == AS_ID_KIND_WEB_APP) {
 			gtk_widget_set_visible (priv->button_details_launch, TRUE);
 		} else {
 			gtk_widget_set_visible (priv->button_details_launch, FALSE);
@@ -713,7 +708,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	/* make history button insensitive if there is none */
 	history = gs_app_get_history (priv->app);
 	switch (gs_app_get_id_kind (priv->app)) {
-	case GS_APP_ID_KIND_WEBAPP:
+	case AS_ID_KIND_WEB_APP:
 		gtk_widget_set_visible (priv->button_history, FALSE);
 		break;
 	default:
@@ -723,7 +718,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	}
 
 	/* don't show missing history on a local file */
-	if (gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL &&
+	if (gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL &&
 	    history->len == 0)
 		gtk_widget_set_visible (priv->button_history, FALSE);
 
@@ -740,7 +735,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	/* is this a repo-release */
 	switch (gs_app_get_kind (priv->app)) {
 	case GS_APP_KIND_SOURCE:
-		gtk_widget_set_visible (priv->infobar_details_repo, gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL);
+		gtk_widget_set_visible (priv->infobar_details_repo, gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 		break;
 	default:
 		gtk_widget_set_visible (priv->infobar_details_repo, FALSE);
@@ -752,7 +747,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	switch (gs_app_get_kind (priv->app)) {
 	case GS_APP_KIND_NORMAL:
 	case GS_APP_KIND_SYSTEM:
-		gtk_widget_set_visible (priv->infobar_details_app_repo, tmp != NULL && gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL);
+		gtk_widget_set_visible (priv->infobar_details_app_repo, tmp != NULL && gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 		break;
 	default:
 		gtk_widget_set_visible (priv->infobar_details_app_repo, FALSE);
@@ -763,7 +758,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	switch (gs_app_get_kind (priv->app)) {
 	case GS_APP_KIND_NORMAL:
 	case GS_APP_KIND_SYSTEM:
-		gtk_widget_set_visible (priv->infobar_details_app_norepo, tmp == NULL && gs_app_get_state (priv->app) == GS_APP_STATE_LOCAL);
+		gtk_widget_set_visible (priv->infobar_details_app_norepo, tmp == NULL && gs_app_get_state (priv->app) == AS_APP_STATE_AVAILABLE_LOCAL);
 		break;
 	default:
 		gtk_widget_set_visible (priv->infobar_details_app_norepo, FALSE);
@@ -772,7 +767,7 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 
 	/* installing a webapp */
 	switch (gs_app_get_id_kind (priv->app)) {
-	case GS_APP_ID_KIND_WEBAPP:
+	case AS_ID_KIND_WEB_APP:
 		gtk_widget_set_visible (priv->infobar_details_webapp, TRUE);
 		break;
 	default:
@@ -782,8 +777,8 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 
 	/* only show the "select addons" string if the app isn't yet installed */
 	switch (gs_app_get_state (priv->app)) {
-	case GS_APP_STATE_INSTALLED:
-	case GS_APP_STATE_UPDATABLE:
+	case AS_APP_STATE_INSTALLED:
+	case AS_APP_STATE_UPDATABLE:
 		gtk_widget_set_visible (priv->label_addons_uninstalled_app, FALSE);
 		break;
 	default:
@@ -796,8 +791,8 @@ gs_shell_details_refresh_all (GsShellDetails *shell_details)
 	for (l = addons; l; l = l->next) {
 		/* show checkboxes in front of addons if the app isn't yet installed */
 		switch (gs_app_get_state (priv->app)) {
-		case GS_APP_STATE_INSTALLED:
-		case GS_APP_STATE_UPDATABLE:
+		case AS_APP_STATE_INSTALLED:
+		case AS_APP_STATE_UPDATABLE:
 			break;
 		default:
 			break;
@@ -1036,8 +1031,8 @@ gs_shell_details_app_installed_cb (GObject *source,
 		g_warning ("failed to install %s: %s",
 			   gs_app_get_id (helper->app),
 			   error->message);
-		gs_app_notify_failed_modal (helper->shell_details->priv->builder,
-					    helper->app,
+		gs_app_notify_failed_modal (helper->app,
+					    gs_shell_get_window (helper->shell_details->priv->shell),
 					    GS_PLUGIN_LOADER_ACTION_INSTALL,
 					    error);
 		g_error_free (error);
@@ -1045,7 +1040,7 @@ gs_shell_details_app_installed_cb (GObject *source,
 	}
 
 	/* only show this if the window is not active */
-	if (gs_app_get_state (helper->app) != GS_APP_STATE_QUEUED &&
+	if (gs_app_get_state (helper->app) != AS_APP_STATE_QUEUED_FOR_INSTALL &&
 	    !gs_shell_is_active (helper->shell_details->priv->shell))
 		gs_app_notify_installed (helper->app);
 	gs_shell_details_refresh_all (helper->shell_details);
@@ -1074,8 +1069,8 @@ gs_shell_details_app_removed_cb (GObject *source,
 		g_warning ("failed to remove %s: %s",
 			   gs_app_get_id (helper->app),
 			   error->message);
-		gs_app_notify_failed_modal (helper->shell_details->priv->builder,
-					    helper->app,
+		gs_app_notify_failed_modal (helper->app,
+					    gs_shell_get_window (helper->shell_details->priv->shell),
 					    GS_PLUGIN_LOADER_ACTION_REMOVE,
 					    error);
 		g_error_free (error);
@@ -1099,9 +1094,7 @@ gs_shell_details_app_remove (GsShellDetails *shell_details, GsApp *app)
 	GString *markup;
 	GtkResponseType response;
 	GtkWidget *dialog;
-	GtkWindow *window;
 
-	window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "window_software"));
 	markup = g_string_new ("");
 	g_string_append_printf (markup,
 				/* TRANSLATORS: this is a prompt message, and
@@ -1110,7 +1103,7 @@ gs_shell_details_app_remove (GsShellDetails *shell_details, GsApp *app)
 				gs_app_get_name (app));
 	g_string_prepend (markup, "<b>");
 	g_string_append (markup, "</b>");
-	dialog = gtk_message_dialog_new (window,
+	dialog = gtk_message_dialog_new (gs_shell_get_window (priv->shell),
 					 GTK_DIALOG_MODAL,
 					 GTK_MESSAGE_QUESTION,
 					 GTK_BUTTONS_CANCEL,
@@ -1122,7 +1115,7 @@ gs_shell_details_app_remove (GsShellDetails *shell_details, GsApp *app)
 						    gs_app_get_name (app));
 	/* TRANSLATORS: this is button text to remove the application */
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Remove"), GTK_RESPONSE_OK);
-	if (gs_app_get_state (app) == GS_APP_STATE_INSTALLED)
+	if (gs_app_get_state (app) == AS_APP_STATE_INSTALLED)
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
 	else
 		response = GTK_RESPONSE_OK; /* pending install */
@@ -1188,7 +1181,7 @@ gs_shell_details_app_install_button_cb (GtkWidget *widget, GsShellDetails *shell
 		if (gs_app_addon_row_get_selected (l->data)) {
 			GsApp *addon = gs_app_addon_row_get_addon (l->data);
 
-			if (gs_app_get_state (addon) == GS_APP_STATE_AVAILABLE)
+			if (gs_app_get_state (addon) == AS_APP_STATE_AVAILABLE)
 				gs_app_set_to_be_installed (addon, TRUE);
 		}
 	}
@@ -1214,8 +1207,8 @@ gs_shell_details_addon_selected_cb (GsAppAddonRow *row,
 	 * triggers an immediate install. Otherwise we'll install the addon
 	 * together with the main app. */
 	switch (gs_app_get_state (priv->app)) {
-	case GS_APP_STATE_INSTALLED:
-	case GS_APP_STATE_UPDATABLE:
+	case AS_APP_STATE_INSTALLED:
+	case AS_APP_STATE_UPDATABLE:
 		if (gs_app_addon_row_get_selected (row))
 			gs_shell_details_app_install (shell_details, addon);
 		else
@@ -1262,13 +1255,10 @@ static void
 gs_shell_details_app_history_button_cb (GtkWidget *widget, GsShellDetails *shell_details)
 {
 	GsShellDetailsPrivate *priv = shell_details->priv;
-	GtkWidget *toplevel;
 
 	gs_history_dialog_set_app (GS_HISTORY_DIALOG (priv->history_dialog), priv->app);
 
-	toplevel = GTK_WIDGET (gtk_builder_get_object (priv->builder, "window_software"));
-	gtk_window_set_transient_for (GTK_WINDOW (priv->history_dialog), GTK_WINDOW (toplevel));
-
+	gtk_window_set_transient_for (GTK_WINDOW (priv->history_dialog), gs_shell_get_window (priv->shell));
 	gtk_window_present (GTK_WINDOW (priv->history_dialog));
 }
 
