@@ -24,6 +24,7 @@
 
 #include <string.h>
 #include <glib/gi18n.h>
+#include <appstream-glib.h>
 
 #include "gs-shell.h"
 #include "gs-shell-installed.h"
@@ -125,8 +126,8 @@ gs_shell_installed_app_removed_cb (GObject *source,
 		g_warning ("failed to remove %s: %s",
 			   gs_app_get_id (app),
 			   error->message);
-		gs_app_notify_failed_modal (priv->builder,
-					    app,
+		gs_app_notify_failed_modal (app,
+					    gs_shell_get_window (priv->shell),
 					    GS_PLUGIN_LOADER_ACTION_REMOVE,
 					    error);
 		g_error_free (error);
@@ -156,10 +157,8 @@ gs_shell_installed_app_remove_cb (GsAppRow *app_row,
 	GString *markup;
 	GtkResponseType response;
 	GtkWidget *dialog;
-	GtkWindow *window;
 	GsShellInstalledHelper *helper;
 
-	window = GTK_WINDOW (gtk_builder_get_object (priv->builder, "window_software"));
 	markup = g_string_new ("");
 	app = gs_app_row_get_app (app_row);
 	g_string_append_printf (markup,
@@ -169,7 +168,7 @@ gs_shell_installed_app_remove_cb (GsAppRow *app_row,
 				gs_app_get_name (app));
 	g_string_prepend (markup, "<b>");
 	g_string_append (markup, "</b>");
-	dialog = gtk_message_dialog_new (window,
+	dialog = gtk_message_dialog_new (gs_shell_get_window (priv->shell),
 					 GTK_DIALOG_MODAL,
 					 GTK_MESSAGE_QUESTION,
 					 GTK_BUTTONS_CANCEL,
@@ -181,7 +180,7 @@ gs_shell_installed_app_remove_cb (GsAppRow *app_row,
 						    gs_app_get_name (app));
 	/* TRANSLATORS: this is button text to remove the application */
 	gtk_dialog_add_button (GTK_DIALOG (dialog), _("Remove"), GTK_RESPONSE_OK);
-	if (gs_app_get_state (app) == GS_APP_STATE_QUEUED)
+	if (gs_app_get_state (app) == AS_APP_STATE_QUEUED_FOR_INSTALL)
 		response = GTK_RESPONSE_OK; /* pending install */
 	else
 		response = gtk_dialog_run (GTK_DIALOG (dialog));
@@ -361,11 +360,11 @@ gs_shell_installed_get_app_sort_key (GsApp *app)
 
 	/* sort installed, removing, other */
 	switch (gs_app_get_state (app)) {
-	case GS_APP_STATE_INSTALLING:
-	case GS_APP_STATE_QUEUED:
+	case AS_APP_STATE_INSTALLING:
+	case AS_APP_STATE_QUEUED_FOR_INSTALL:
 		g_string_append (key, "1:");
 		break;
-	case GS_APP_STATE_REMOVING:
+	case AS_APP_STATE_REMOVING:
 		g_string_append (key, "2:");
 		break;
 	default:
@@ -375,8 +374,8 @@ gs_shell_installed_get_app_sort_key (GsApp *app)
 
 	/* sort desktop files, then addons */
 	switch (gs_app_get_id_kind (app)) {
-	case GS_APP_ID_KIND_DESKTOP:
-	case GS_APP_ID_KIND_WEBAPP:
+	case AS_ID_KIND_DESKTOP:
+	case AS_ID_KIND_WEB_APP:
 		g_string_append (key, "1:");
 		break;
 	default:
@@ -443,11 +442,11 @@ out:
 static gboolean
 gs_shell_installed_is_addon_id_kind (GsApp *app)
 {
-	GsAppIdKind id_kind;
+	AsIdKind id_kind;
 	id_kind = gs_app_get_id_kind (app);
-	if (id_kind == GS_APP_ID_KIND_DESKTOP)
+	if (id_kind == AS_ID_KIND_DESKTOP)
 		return FALSE;
-	if (id_kind == GS_APP_ID_KIND_WEBAPP)
+	if (id_kind == AS_ID_KIND_WEB_APP)
 		return FALSE;
 	return TRUE;
 }
@@ -455,7 +454,7 @@ gs_shell_installed_is_addon_id_kind (GsApp *app)
 static gboolean
 gs_shell_installed_is_system_application (GsApp *app)
 {
-	if (gs_app_get_id_kind (app) == GS_APP_ID_KIND_DESKTOP &&
+	if (gs_app_get_id_kind (app) == AS_ID_KIND_DESKTOP &&
 	    gs_app_get_kind (app) == GS_APP_KIND_SYSTEM)
 		return TRUE;
 	return FALSE;
