@@ -285,7 +285,7 @@ gs_shell_updates_update_ui_state (GsShellUpdates *shell_updates)
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH_HAS_UPDATES:
 	case GS_SHELL_UPDATES_STATE_ACTION_REFRESH_NO_UPDATES:
 		gtk_image_set_from_icon_name (GTK_IMAGE (widget),
-					      "media-playback-stop-symbolic", 0);
+					      "media-playback-stop-symbolic", GTK_ICON_SIZE_MENU);
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_refresh"));
 		gtk_widget_show (widget);
 		break;
@@ -478,9 +478,7 @@ gs_shell_updates_refresh (GsShellUpdates *shell_updates,
 	if (gs_shell_get_mode (priv->shell) == GS_SHELL_MODE_UPDATES) {
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "buttonbox_main"));
 		gtk_widget_show (widget);
-	}
 
-	if (gs_shell_get_mode (priv->shell) == GS_SHELL_MODE_UPDATES) {
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "button_refresh"));
 		gtk_widget_set_visible (widget, TRUE);
 	}
@@ -524,14 +522,11 @@ show_update_details (GsApp *app, GsShellUpdates *shell_updates)
 {
 	GsShellUpdatesPrivate *priv = shell_updates->priv;
 	GtkWidget *dialog;
-	GtkWidget *toplevel;
 
 	dialog = gs_update_dialog_new ();
 	gs_update_dialog_show_update_details (GS_UPDATE_DIALOG (dialog), app);
 
-	toplevel = GTK_WIDGET (gtk_builder_get_object (priv->builder, "window_software"));
-	gtk_window_set_transient_for (GTK_WINDOW (dialog), GTK_WINDOW (toplevel));
-
+	gtk_window_set_transient_for (GTK_WINDOW (dialog), gs_shell_get_window (priv->shell));
 	gtk_window_present (GTK_WINDOW (dialog));
 }
 
@@ -720,8 +715,7 @@ gs_shell_updates_button_refresh_cb (GtkWidget *widget,
 		gs_shell_updates_get_new_updates (shell_updates);
 		break;
 	case PK_NETWORK_ENUM_OFFLINE:
-		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "window_software"));
-		dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
+		dialog = gtk_message_dialog_new (gs_shell_get_window (priv->shell),
 						 GTK_DIALOG_MODAL |
 						 GTK_DIALOG_USE_HEADER_BAR |
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -748,8 +742,7 @@ gs_shell_updates_button_refresh_cb (GtkWidget *widget,
 			gs_shell_updates_get_new_updates (shell_updates);
 			break;
 		}
-		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "window_software"));
-		dialog = gtk_message_dialog_new (GTK_WINDOW (widget),
+		dialog = gtk_message_dialog_new (gs_shell_get_window (priv->shell),
 						 GTK_DIALOG_MODAL |
 						 GTK_DIALOG_USE_HEADER_BAR |
 						 GTK_DIALOG_DESTROY_WITH_PARENT,
