@@ -130,7 +130,7 @@ gs_app_notify_installed (GsApp *app)
 	 * has been successfully installed */
 	summary = g_strdup_printf (_("%s is now installed"), gs_app_get_name (app));
 	n = g_notification_new (summary);
-	if (gs_app_get_id_kind (app) == GS_APP_ID_KIND_DESKTOP) {
+	if (gs_app_get_id_kind (app) == AS_ID_KIND_DESKTOP) {
 		/* TRANSLATORS: this is button that opens the newly installed application */
 		g_notification_add_button_with_target (n, _("Launch"),
 						       "app.launch", "s",
@@ -147,13 +147,12 @@ gs_app_notify_installed (GsApp *app)
  * gs_app_notify_failed_modal:
  **/
 void
-gs_app_notify_failed_modal (GtkBuilder *builder,
-			    GsApp *app,
+gs_app_notify_failed_modal (GsApp *app,
+			    GtkWindow *parent_window,
 			    GsPluginLoaderAction action,
 			    const GError *error)
 {
 	GtkWidget *dialog;
-	GtkWindow *window;
 	gchar *title;
 	gchar *msg;
 
@@ -173,8 +172,7 @@ gs_app_notify_failed_modal (GtkBuilder *builder,
 		g_assert_not_reached ();
 		break;
 	}
-	window = GTK_WINDOW (gtk_builder_get_object (builder, "window_software"));
-	dialog = gtk_message_dialog_new (window,
+	dialog = gtk_message_dialog_new (parent_window,
 					 GTK_DIALOG_MODAL |
 					 GTK_DIALOG_DESTROY_WITH_PARENT,
 					 GTK_MESSAGE_ERROR,
