@@ -35,8 +35,8 @@ void	 gs_container_remove_all	(GtkContainer	*container);
 void	 gs_grab_focus_when_mapped	(GtkWidget	*widget);
 
 void	 gs_app_notify_installed	(GsApp		*app);
-void	 gs_app_notify_failed_modal	(GtkBuilder	*builder,
-					 GsApp		*app,
+void	 gs_app_notify_failed_modal	(GsApp		*app,
+					 GtkWindow	*parent_window,
 					 GsPluginLoaderAction action,
 					 const GError	*error);
 
