@@ -101,7 +101,7 @@ const gchar **
 gs_plugin_get_deps (GsPlugin *plugin)
 {
 	static const gchar *deps[] = {
-		"datadir-apps",		/* set the state using the installed file */
+		"hardcoded-categories",	/* need category list */
 		NULL };
 	return deps;
 }
@@ -136,9 +136,15 @@ gs_plugin_startup (GsPlugin *plugin, GCancellable *cancellable, GError **error)
 
 	/* Parse the XML */
 	gs_profile_start (plugin->profile, "appstream::startup");
+	if (g_getenv ("GNOME_SOFTWARE_PREFER_LOCAL") != NULL) {
+		as_store_set_add_flags (plugin->priv->store,
+					AS_STORE_ADD_FLAG_PREFER_LOCAL);
+	}
 	ret = as_store_load (plugin->priv->store,
 			     AS_STORE_LOAD_FLAG_APP_INFO_SYSTEM |
 			     AS_STORE_LOAD_FLAG_APP_INFO_USER |
+			     AS_STORE_LOAD_FLAG_APPDATA |
+			     AS_STORE_LOAD_FLAG_DESKTOP |
 			     AS_STORE_LOAD_FLAG_APP_INSTALL,
 			     cancellable,
 			     error);
@@ -171,49 +177,6 @@ out:
 	return ret;
 }
 
-/**
- * gs_plugin_refine_search_pixbuf:
- *
- * This method allows us to cope with metadata like this:
- *
- * <icon type="local">gnome-chess</icon>
- * <icon type="local">geary</icon>
- *
- * Where .../app-info/icons/gnome-chess.png and .../app-info/icons/geary.svg
- * exist.
- *
- * Basically, we have to stick on the extension and stat() each file in turn.
- */
-static gchar *
-gs_plugin_refine_search_pixbuf (GsPlugin *plugin,
-				const gchar *icon_dir,
-				const gchar *icon)
-{
-	const gchar *exensions[] = { "png",
-				     "svg",
-				     "svgz",
-				     "gif",
-				     "ico",
-				     "xcf",
-				     NULL };
-	gchar *icon_path;
-	guint i;
-
-	/* exists */
-	for (i = 0; exensions[i] != NULL; i++) {
-		icon_path = g_strdup_printf ("%s/%s.%s",
-					     icon_dir,
-					     icon,
-					     exensions[i]);
-		if (g_file_test (icon_path, G_FILE_TEST_EXISTS))
-			goto out;
-		g_free (icon_path);
-		icon_path = NULL;
-	}
-out:
-	return icon_path;
-}
-
 /**
  * gs_plugin_refine_item_pixbuf:
  */
@@ -249,28 +212,14 @@ gs_plugin_refine_item_pixbuf (GsPlugin *plugin, GsApp *app, AsApp *item)
 		gs_app_set_icon (app, icon_path);
 		ret = gs_app_load_icon (app, &error);
 		if (!ret) {
-			g_warning ("falling back to searching for %s", icon_path);
-			g_clear_error (&error);
-			g_free (icon_path);
-
-			/* we are not going to be doing this forever,
-			 * SO FIX YOUR APPSTREAM METADATA */
-			icon_path = gs_plugin_refine_search_pixbuf (plugin, icon_dir, icon);
-			if (icon_path == NULL) {
-				g_warning ("failed to load cached icon %s", icon);
-				goto out;
-			}
-			gs_app_set_icon (app, icon_path);
-			ret = gs_app_load_icon (app, &error);
-			if (!ret) {
-				g_warning ("failed to load cached icon %s: %s",
-					   icon, error->message);
-				g_error_free (error);
-			}
+			g_warning ("failed to load cached icon %s: %s",
+				   icon, error->message);
+			g_error_free (error);
 			goto out;
 		}
 		break;
 	default:
+		g_warning ("icon kind unknown for %s", as_app_get_id_full (item));
 		break;
 	}
 out:
@@ -315,14 +264,10 @@ gs_plugin_refine_add_addons (GsPlugin *plugin, GsApp *app, AsApp *item)
 static void
 gs_plugin_refine_add_screenshots (GsApp *app, AsApp *item)
 {
-	AsImage *im;
 	AsScreenshot *ss;
-	AsScreenshotKind ss_kind;
 	GPtrArray *images_as;
 	GPtrArray *screenshots_as;
-	GsScreenshot *screenshot;
 	guint i;
-	guint j;
 
 	/* do we have any to add */
 	screenshots_as = as_app_get_screenshots (item);
@@ -341,25 +286,9 @@ gs_plugin_refine_add_screenshots (GsApp *app, AsApp *item)
 		images_as = as_screenshot_get_images (ss);
 		if (images_as->len == 0)
 			continue;
-		ss_kind = as_screenshot_get_kind (ss);
-		if (ss_kind == AS_SCREENSHOT_KIND_UNKNOWN)
+		if (as_screenshot_get_kind (ss) == AS_SCREENSHOT_KIND_UNKNOWN)
 			continue;
-
-		/* create a new application screenshot and add each image */
-		screenshot = gs_screenshot_new ();
-		gs_screenshot_set_is_default (screenshot,
-					      ss_kind == AS_SCREENSHOT_KIND_DEFAULT);
-		gs_screenshot_set_caption (screenshot,
-					   as_screenshot_get_caption (ss, NULL));
-		for (j = 0; j < images_as->len; j++) {
-			im = g_ptr_array_index (images_as, j);
-			gs_screenshot_add_image	(screenshot,
-						 as_image_get_url (im),
-						 as_image_get_width (im),
-						 as_image_get_height (im));
-		}
-		gs_app_add_screenshot (app, screenshot);
-		g_object_unref (screenshot);
+		gs_app_add_screenshot (app, ss);
 	}
 }
 
@@ -422,6 +351,48 @@ gs_plugin_appstream_is_recent_release (AsApp *app)
 	return secs / (60 * 60 * 24) < 365;
 }
 
+/**
+ * gs_plugin_appstream_are_screenshots_perfect:
+ */
+static gboolean
+gs_plugin_appstream_are_screenshots_perfect (AsApp *app)
+{
+	AsImage *image;
+	AsScreenshot *screenshot;
+	GPtrArray *screenshots;
+	guint height;
+	guint i;
+	guint width;
+
+	screenshots = as_app_get_screenshots (app);
+	if (screenshots->len == 0)
+		return FALSE;
+	for (i = 0; i < screenshots->len; i++) {
+
+		/* get the source image as the thumbs will be resized & padded */
+		screenshot = g_ptr_array_index (screenshots, i);
+		image = as_screenshot_get_source (screenshot);
+		if (image == NULL)
+			return FALSE;
+
+		width = as_image_get_width (image);
+		height = as_image_get_height (image);
+
+		/* too small */
+		if (width < AS_IMAGE_LARGE_WIDTH || height < AS_IMAGE_LARGE_HEIGHT)
+			return FALSE;
+
+		/* too large */
+		if (width > AS_IMAGE_LARGE_WIDTH * 2 || height > AS_IMAGE_LARGE_HEIGHT * 2)
+			return FALSE;
+
+		/* not 16:9 */
+		if ((width / 16) * 9 != height)
+			return FALSE;
+	}
+	return TRUE;
+}
+
 /**
  * gs_plugin_refine_item:
  */
@@ -433,9 +404,11 @@ gs_plugin_refine_item (GsPlugin *plugin,
 {
 	GHashTable *urls;
 	GPtrArray *pkgnames;
+	GPtrArray *kudos;
 	const gchar *tmp;
 	gboolean ret = TRUE;
 	gchar *from_xml;
+	guint i;
 
 	/* is an app */
 	if (gs_app_get_kind (app) == GS_APP_KIND_UNKNOWN ||
@@ -447,6 +420,27 @@ gs_plugin_refine_item (GsPlugin *plugin,
 		}
 	}
 
+	/* is installed already */
+	if (gs_app_get_state (app) == AS_APP_STATE_UNKNOWN) {
+		switch (as_app_get_source_kind (item)) {
+		case AS_APP_SOURCE_KIND_APPDATA:
+		case AS_APP_SOURCE_KIND_DESKTOP:
+			gs_app_set_kind (app, GS_APP_KIND_NORMAL);
+		case AS_APP_SOURCE_KIND_METAINFO:
+			gs_app_set_state (app, AS_APP_STATE_INSTALLED);
+			break;
+		default:
+			break;
+		}
+	}
+
+	/* give the desktopdb plugin a fighting chance */
+	if (as_app_get_source_file (item) != NULL &&
+	    gs_app_get_metadata_item (app, "DataDir::desktop-filename") == NULL) {
+		gs_app_set_metadata (app, "DataDir::desktop-filename",
+				     as_app_get_source_file (item));
+	}
+
 	/* set id */
 	if (as_app_get_id (item) != NULL && gs_app_get_id (app) == NULL)
 		gs_app_set_id (app, as_app_get_id (item));
@@ -470,13 +464,13 @@ gs_plugin_refine_item (GsPlugin *plugin,
 	/* add urls */
 	urls = as_app_get_urls (item);
 	if (g_hash_table_size (urls) > 0 &&
-	    gs_app_get_url (app, GS_APP_URL_KIND_HOMEPAGE) == NULL) {
+	    gs_app_get_url (app, AS_URL_KIND_HOMEPAGE) == NULL) {
 		GList *keys;
 		GList *l;
 		keys = g_hash_table_get_keys (urls);
 		for (l = keys; l != NULL; l = l->next) {
 			gs_app_set_url (app,
-					l->data,
+					as_url_kind_from_string (l->data),
 					g_hash_table_lookup (urls, l->data));
 		}
 		g_list_free (keys);
@@ -527,37 +521,8 @@ gs_plugin_refine_item (GsPlugin *plugin,
 		gs_app_set_kind (app, GS_APP_KIND_SYSTEM);
 
 	/* set id kind */
-	if (gs_app_get_id_kind (app) == GS_APP_ID_KIND_UNKNOWN) {
-		switch (as_app_get_id_kind (item)) {
-		case AS_ID_KIND_UNKNOWN:
-			gs_app_set_id_kind (app, GS_APP_ID_KIND_UNKNOWN);
-			break;
-		case AS_ID_KIND_DESKTOP:
-			gs_app_set_id_kind (app, GS_APP_ID_KIND_DESKTOP);
-			break;
-		case AS_ID_KIND_FONT:
-			gs_app_set_id_kind (app, GS_APP_ID_KIND_FONT);
-			break;
-		case AS_ID_KIND_CODEC:
-			gs_app_set_id_kind (app, GS_APP_ID_KIND_CODEC);
-			break;
-		case AS_ID_KIND_INPUT_METHOD:
-			gs_app_set_id_kind (app, GS_APP_ID_KIND_INPUT_METHOD);
-			break;
-		case AS_ID_KIND_WEB_APP:
-			gs_app_set_id_kind (app, GS_APP_ID_KIND_WEBAPP);
-			break;
-		case AS_ID_KIND_SOURCE:
-			/* handled above */
-			break;
-		case AS_ID_KIND_ADDON:
-			gs_app_set_id_kind (app, GS_APP_ID_KIND_ADDON);
-			break;
-		default:
-			g_warning ("Unhandled AsIdKind '%s'", as_id_kind_to_string (as_app_get_id_kind (item)));
-			break;
-		}
-	}
+	if (gs_app_get_id_kind (app) == AS_ID_KIND_UNKNOWN)
+		gs_app_set_id_kind (app, as_app_get_id_kind (item));
 
 	/* set package names */
 	pkgnames = as_app_get_pkgnames (item);
@@ -570,6 +535,10 @@ gs_plugin_refine_item (GsPlugin *plugin,
 	/* set screenshots */
 	gs_plugin_refine_add_screenshots (app, item);
 
+	/* are the screenshots perfect */
+	if (gs_plugin_appstream_are_screenshots_perfect (item))
+		gs_app_add_kudo (app, GS_APP_KUDO_PERFECT_SCREENSHOTS);
+
 	/* was this application released recently */
 	if (gs_plugin_appstream_is_recent_release (item))
 		gs_app_add_kudo (app, GS_APP_KUDO_RECENT_RELEASE);
@@ -593,6 +562,32 @@ gs_plugin_refine_item (GsPlugin *plugin,
 		gs_app_add_kudo (app, GS_APP_KUDO_POPULAR);
 	if (as_app_get_metadata_item (item, "X-IBus-Symbol") != NULL)
 		gs_app_add_kudo (app, GS_APP_KUDO_IBUS_HAS_SYMBOL);
+
+	/* add new-style kudos */
+	kudos = as_app_get_kudos (item);
+	for (i = 0; i < kudos->len; i++) {
+		tmp = g_ptr_array_index (kudos, i);
+		switch (as_kudo_kind_from_string (tmp)) {
+		case AS_KUDO_KIND_SEARCH_PROVIDER:
+			gs_app_add_kudo (app, GS_APP_KUDO_SEARCH_PROVIDER);
+			break;
+		case AS_KUDO_KIND_USER_DOCS:
+			gs_app_add_kudo (app, GS_APP_KUDO_INSTALLS_USER_DOCS);
+			break;
+		case AS_KUDO_KIND_APP_MENU:
+			gs_app_add_kudo (app, GS_APP_KUDO_USES_APP_MENU);
+			break;
+		case AS_KUDO_KIND_MODERN_TOOLKIT:
+			gs_app_add_kudo (app, GS_APP_KUDO_MODERN_TOOLKIT);
+			break;
+		case AS_KUDO_KIND_NOTIFICATIONS:
+			gs_app_add_kudo (app, GS_APP_KUDO_USES_NOTIFICATIONS);
+			break;
+		default:
+			g_debug ("no idea how to handle kudo '%s'", tmp);
+			break;
+		}
+	}
 out:
 	return ret;
 }
@@ -767,6 +762,7 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 		if (!ret)
 			goto out;
 		gs_plugin_add_app (list, app);
+		g_object_unref (app);
 	}
 	gs_profile_stop (plugin->profile, "appstream::add-category-apps");
 out:
@@ -808,6 +804,7 @@ gs_plugin_add_search (GsPlugin *plugin,
 			if (!ret)
 				goto out;
 			gs_plugin_add_app (list, app);
+			g_object_unref (app);
 		}
 	}
 	gs_profile_stop (plugin->profile, "appstream::search");
@@ -815,6 +812,94 @@ out:
 	return ret;
 }
 
+/**
+ * gs_plugin_add_installed:
+ */
+gboolean
+gs_plugin_add_installed (GsPlugin *plugin,
+			 GList **list,
+			 GCancellable *cancellable,
+			 GError **error)
+{
+	AsApp *item;
+	gboolean ret = TRUE;
+	GPtrArray *array;
+	GsApp *app;
+	guint i;
+
+	/* load XML files */
+	if (g_once_init_enter (&plugin->priv->done_init)) {
+		ret = gs_plugin_startup (plugin, cancellable, error);
+		g_once_init_leave (&plugin->priv->done_init, TRUE);
+		if (!ret)
+			goto out;
+	}
+
+	/* search categories for the search term */
+	gs_profile_start (plugin->profile, "appstream::add_installed");
+	array = as_store_get_apps (plugin->priv->store);
+	for (i = 0; i < array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		if (as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_APPDATA) {
+			app = gs_app_new (as_app_get_id_full (item));
+			ret = gs_plugin_refine_item (plugin, app, item, error);
+			if (!ret)
+				goto out;
+			gs_plugin_add_app (list, app);
+			g_object_unref (app);
+		}
+	}
+	gs_profile_stop (plugin->profile, "appstream::add_installed");
+out:
+	return ret;
+}
+
+/**
+ * gs_plugin_add_categories_for_app:
+ */
+static void
+gs_plugin_add_categories_for_app (GList *list, AsApp *app)
+{
+	GList *children;
+	GList *l;
+	GList *l2;
+	GsCategory *category;
+	GsCategory *parent;
+	gboolean found_subcat;
+
+	/* does it match the main category */
+	for (l = list; l != NULL; l = l->next) {
+		parent = GS_CATEGORY (l->data);
+		if (!as_app_has_category (app, gs_category_get_id (parent)))
+			continue;
+		gs_category_increment_size (parent);
+
+		/* does it match any sub-categories */
+		found_subcat = FALSE;
+		children = gs_category_get_subcategories (parent);
+		for (l2 = children; l2 != NULL; l2 = l2->next) {
+			category = GS_CATEGORY (l2->data);
+			if (!as_app_has_category (app, gs_category_get_id (category)))
+				continue;
+			gs_category_increment_size (category);
+			found_subcat = TRUE;
+		}
+		g_list_free (children);
+
+		/* matching the main category but no subcategories means we have
+		 * to create a new 'Other' subcategory manually */
+		if (!found_subcat) {
+			category = gs_category_find_child (parent, "other");
+			if (category == NULL) {
+				category = gs_category_new (parent, "other", NULL);
+				gs_category_add_subcategory (parent, category);
+			}
+			as_app_add_category (app, gs_category_get_id (category), -1);
+			gs_category_increment_size (category);
+		}
+	}
+}
+
 /**
  * gs_plugin_add_categories:
  */
@@ -824,16 +909,9 @@ gs_plugin_add_categories (GsPlugin *plugin,
 			  GCancellable *cancellable,
 			  GError **error)
 {
-	AsApp *item;
-	const gchar *search_id1;
-	const gchar *search_id2 = NULL;
-	gboolean ret = TRUE;
-	GList *l;
-	GList *l2;
-	GList *children;
+	AsApp *app;
 	GPtrArray *array;
-	GsCategory *category;
-	GsCategory *parent;
+	gboolean ret = TRUE;
 	guint i;
 
 	/* load XML files */
@@ -847,35 +925,169 @@ gs_plugin_add_categories (GsPlugin *plugin,
 	/* find out how many packages are in each category */
 	gs_profile_start (plugin->profile, "appstream::add-categories");
 	array = as_store_get_apps (plugin->priv->store);
-	for (l = *list; l != NULL; l = l->next) {
-		parent = GS_CATEGORY (l->data);
-		search_id2 = gs_category_get_id (parent);
-		children = gs_category_get_subcategories (parent);
-		for (l2 = children; l2 != NULL; l2 = l2->next) {
-			category = GS_CATEGORY (l2->data);
-
-			/* just look at each app in turn */
-			for (i = 0; i < array->len; i++) {
-				item = g_ptr_array_index (array, i);
-				if (as_app_get_id (item) == NULL)
-					continue;
-				if (as_app_get_priority (item) < 0)
-					continue;
-				if (!as_app_has_category (item, search_id2))
-					continue;
-				search_id1 = gs_category_get_id (category);
-				if (search_id1 != NULL &&
-				    !as_app_has_category (item, search_id1))
-					continue;
-
-				/* we have another result */
-				gs_category_increment_size (category);
-				gs_category_increment_size (parent);
-			}
-		}
-		g_list_free (children);
+	for (i = 0; i < array->len; i++) {
+		app = g_ptr_array_index (array, i);
+		if (as_app_get_id (app) == NULL)
+			continue;
+		if (as_app_get_priority (app) < 0)
+			continue;
+		gs_plugin_add_categories_for_app (*list, app);
 	}
 	gs_profile_stop (plugin->profile, "appstream::add-categories");
 out:
 	return ret;
 }
+
+/**
+ * gs_plugin_add_popular_from_category:
+ */
+static gboolean
+gs_plugin_add_popular_from_category (GsPlugin *plugin,
+				     const gchar *category,
+				     GList **list,
+				     GHashTable *ignore_apps,
+				     GError **error)
+{
+	AsApp *item;
+	GPtrArray *array;
+	GsApp *app;
+	gboolean ret = TRUE;
+	guint i;
+
+	/* search categories for the search term */
+	array = as_store_get_apps (plugin->priv->store);
+	for (i = 0; i < array->len; i++) {
+		item = g_ptr_array_index (array, i);
+
+		/* find not-installed desktop application with long descriptions
+		 * and perfect screenshots and that we've not suggested before */
+		if (as_app_get_state (item) == AS_APP_STATE_INSTALLED)
+			continue;
+		if (as_app_get_id_kind (item) != AS_ID_KIND_DESKTOP)
+			continue;
+		if (as_app_get_description (item, NULL) == NULL)
+			continue;
+		if (g_hash_table_lookup (ignore_apps, as_app_get_id_full (item)) != NULL)
+			continue;
+		if (!as_app_has_category (item, category))
+			continue;
+
+		/* add application */
+		app = gs_app_new (as_app_get_id_full (item));
+		ret = gs_plugin_refine_item (plugin, app, item, error);
+		if (!ret)
+			goto out;
+
+		/* only suggest awesome applications */
+		if ((gs_app_get_kudos (app) & GS_APP_KUDO_PERFECT_SCREENSHOTS) > 0 &&
+		    gs_app_get_kudos_weight (app) >= 4) {
+			g_debug ("suggesting %s as others installed from %s",
+				 as_app_get_id (item), category);
+			gs_plugin_add_app (list, app);
+			g_hash_table_insert (ignore_apps,
+					     (gpointer) as_app_get_id_full (item),
+					     GINT_TO_POINTER (1));
+		}
+		g_object_unref (app);
+	}
+out:
+	return ret;
+}
+
+/**
+ * gs_plugin_add_popular:
+ */
+gboolean
+gs_plugin_add_popular (GsPlugin *plugin,
+			GList **list,
+			GCancellable *cancellable,
+			GError **error)
+{
+	AsApp *item;
+	GHashTable *ignore_apps = NULL;
+	GHashTable *ignore_cats = NULL;
+	GPtrArray *array;
+	GPtrArray *categories;
+	const gchar *tmp;
+	gboolean ret = TRUE;
+	guint i;
+	guint j;
+
+	/* load XML files */
+	if (g_once_init_enter (&plugin->priv->done_init)) {
+		ret = gs_plugin_startup (plugin, cancellable, error);
+		g_once_init_leave (&plugin->priv->done_init, TRUE);
+		if (!ret)
+			goto out;
+	}
+
+	/* ignore main categories */
+	ignore_cats = g_hash_table_new (g_str_hash, g_str_equal);
+	g_hash_table_insert (ignore_cats, (gpointer) "Audio", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Development", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Education", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Game", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Graphics", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Network", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Office", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Science", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "System", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Utility", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Video", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "Addons", GINT_TO_POINTER (1));
+
+	/* ignore core apps */
+	g_hash_table_insert (ignore_cats, (gpointer) "Core", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "PackageManager", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "TerminalEmulator", GINT_TO_POINTER (1));
+	g_hash_table_insert (ignore_cats, (gpointer) "other", GINT_TO_POINTER (1));
+
+	/* get already installed applications */
+	ignore_apps = g_hash_table_new (g_str_hash, g_str_equal);
+	array = as_store_get_apps (plugin->priv->store);
+	for (i = 0; i < array->len; i++) {
+		item = g_ptr_array_index (array, i);
+		if (as_app_get_state (item) != AS_APP_STATE_INSTALLED)
+			continue;
+		g_hash_table_insert (ignore_apps,
+				     (gpointer) as_app_get_id_full (item),
+				     GINT_TO_POINTER (1));
+	}
+
+	/* search categories for the search term */
+	gs_profile_start (plugin->profile, "appstream::add_popular");
+	for (i = 0; i < array->len; i++) {
+		item = g_ptr_array_index (array, i);
+
+		/* find installed desktop applications */
+		if (as_app_get_state (item) != AS_APP_STATE_INSTALLED)
+			continue;
+		if (as_app_get_id_kind (item) != AS_ID_KIND_DESKTOP)
+			continue;
+		if (as_app_get_source_kind (item) == AS_APP_SOURCE_KIND_DESKTOP)
+			continue;
+
+		/* find non-installed apps with appdata in any category */
+		categories = as_app_get_categories (item);
+		for (j = 0; j < categories->len; j++) {
+			tmp = g_ptr_array_index (categories, j);
+			if (g_hash_table_lookup (ignore_cats, tmp) != NULL)
+				continue;
+			ret = gs_plugin_add_popular_from_category (plugin,
+								   tmp,
+								   list,
+								   ignore_apps,
+								   error);
+			if (!ret)
+				goto out;
+		}
+
+	}
+	gs_profile_stop (plugin->profile, "appstream::add_popular");
+out:
+	if (ignore_cats != NULL)
+		g_hash_table_unref (ignore_cats);
+	if (ignore_apps != NULL)
+		g_hash_table_unref (ignore_apps);
+	return ret;
+}
