@@ -96,7 +96,7 @@ gs_plugin_add_updates (GsPlugin *plugin,
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, "Boxes");
 	gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, "Do not segfault when using newer versons of libvirt.");
 	gs_app_set_kind (app, GS_APP_KIND_NORMAL);
-	gs_app_set_id_kind (app, GS_APP_ID_KIND_DESKTOP);
+	gs_app_set_id_kind (app, AS_ID_KIND_DESKTOP);
 	gs_plugin_add_app (list, app);
 
 	/* add an OS update */
@@ -104,7 +104,7 @@ gs_plugin_add_updates (GsPlugin *plugin,
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, "libvirt-glib-devel");
 	gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, "Fix several memory leaks.");
 	gs_app_set_kind (app, GS_APP_KIND_PACKAGE);
-	gs_app_set_id_kind (app, GS_APP_ID_KIND_DESKTOP);
+	gs_app_set_id_kind (app, AS_ID_KIND_DESKTOP);
 	gs_plugin_add_app (list, app);
 
 	/* add a second OS update */
@@ -112,7 +112,7 @@ gs_plugin_add_updates (GsPlugin *plugin,
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, "gnome-boxes-libs");
 	gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, "Do not segfault when using newer versons of libvirt.");
 	gs_app_set_kind (app, GS_APP_KIND_PACKAGE);
-	gs_app_set_id_kind (app, GS_APP_ID_KIND_DESKTOP);
+	gs_app_set_id_kind (app, AS_ID_KIND_DESKTOP);
 	gs_plugin_add_app (list, app);
 
 	return TRUE;
@@ -132,10 +132,10 @@ gs_plugin_add_installed (GsPlugin *plugin,
 	app = gs_app_new ("gnome-power-manager");
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, "Power Manager");
 	gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, "Power Management Program");
-	gs_app_set_state (app, GS_APP_STATE_AVAILABLE);
+	gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 	gs_app_set_kind (app, GS_APP_KIND_NORMAL);
 	gs_plugin_add_app (list, app);
-	gs_app_set_id_kind (app, GS_APP_ID_KIND_DESKTOP);
+	gs_app_set_id_kind (app, AS_ID_KIND_DESKTOP);
 
 	return TRUE;
 }
@@ -154,10 +154,10 @@ gs_plugin_add_popular (GsPlugin *plugin,
 	app = gs_app_new ("gnome-power-manager");
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, "Power Manager");
 	gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, "Power Management Program");
-	gs_app_set_state (app, GS_APP_STATE_AVAILABLE);
+	gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 	gs_app_set_kind (app, GS_APP_KIND_NORMAL);
 	gs_plugin_add_app (list, app);
-	gs_app_set_id_kind (app, GS_APP_ID_KIND_DESKTOP);
+	gs_app_set_id_kind (app, AS_ID_KIND_DESKTOP);
 
 	return TRUE;
 }
@@ -201,11 +201,11 @@ gs_plugin_add_category_apps (GsPlugin *plugin,
 	app = gs_app_new ("gnome-boxes");
 	gs_app_set_name (app, GS_APP_QUALITY_NORMAL, "Boxes");
 	gs_app_set_summary (app, GS_APP_QUALITY_NORMAL, "View and use virtual machines");
-	gs_app_set_url (app, GS_APP_URL_KIND_HOMEPAGE, "http://www.box.org");
+	gs_app_set_url (app, AS_URL_KIND_HOMEPAGE, "http://www.box.org");
 	gs_app_set_kind (app, GS_APP_KIND_NORMAL);
-	gs_app_set_state (app, GS_APP_STATE_AVAILABLE);
+	gs_app_set_state (app, AS_APP_STATE_AVAILABLE);
 	gs_app_set_pixbuf (app, gdk_pixbuf_new_from_file ("/usr/share/icons/hicolor/48x48/apps/gnome-boxes.png", NULL));
-	gs_app_set_id_kind (app, GS_APP_ID_KIND_DESKTOP);
+	gs_app_set_id_kind (app, AS_ID_KIND_DESKTOP);
 	gs_plugin_add_app (list, app);
 	return TRUE;
 }
